#!/usr/bin/env node
"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const commander_1 = require("commander");
const promises_1 = __importDefault(require("fs/promises"));
const compiler_1 = require("../compiler");
const interpreter_1 = require("../interpreter");
const program = new commander_1.Command();
program
    .command("compile <path>")
    .option("-o, --out <outpath>", "output file path")
    .action(async (path, { out }) => {
    const content = await promises_1.default.readFile(path).then((c) => c.toString());
    const compiled = compiler_1.compile(compiler_1.parse(content)).code;
    if (out) {
        promises_1.default.writeFile(out, compiled);
    }
    else {
        console.log(compiled);
    }
});
program
    .command("run <path>")
    .option("-i, --input <input...>", "input characters")
    .option("-r, --no-compiler", "run raw brainfuck code")
    .action(async (path, { input, compiler }) => {
    const content = await promises_1.default.readFile(path).then((c) => c.toString());
    const compiled = compiler ? compiler_1.compile(compiler_1.parse(content)).code : content;
    interpreter_1.interpret(compiled, input?.map(parseInt));
});
program.parse(process.argv);
